#!/bin/sh

EXT_IF=eth1
INT_IF=eth0
INT_NET="10.1.1.0/24"

EXT_IP=`/sbin/ifconfig | grep $EXT_IF -A 1 | grep inet \
	| sed 's/  B.*$//g' | sed 's/^.*://g'`

case $1 in
	start)
		echo "Adding firewall rules..."
		echo "Internal network: $INT_NET"
		echo "External IP: $EXT_IP"
		/usr/sbin/iptables -F
		/usr/sbin/iptables -t nat -F

# masquerading
		/usr/sbin/iptables -t nat -A POSTROUTING	\
			-o $EXT_IF				\
			-j SNAT --to-source $EXT_IP

# spoof drop
		/usr/sbin/iptables -t nat -A PREROUTING		\
			-i $EXT_IF				\
			-s $INT_NET				\
			-j DROP

# accept already established connections
#	/usr/sbin/iptables -A FORWARD			\
#		-i $EXT_IF				\
#		-m state --state ESTABLISHED,RELATED	\
#		-j ACCEPT

# forwarding

# Gnutella
		GNUTELLA_SRV=10.1.1.10
		/usr/sbin/iptables -t nat -A PREROUTING		\
			-i $EXT_IF				\
			-p tcp --dport 4110			\
			-j DNAT --to-destination $GNUTELLA_SRV
		/usr/sbin/iptables -t nat -A PREROUTING		\
			-i $EXT_IF				\
			-p udp --dport 4111			\
			-j DNAT --to-destination $GNUTELLA_SRV

# VNC
		VNC_SRV=10.1.1.10
		/usr/sbin/iptables -t nat -A PREROUTING		\
			-i $EXT_IF				\
			-p tcp --dport 5800			\
			-j DNAT --to-destination $VNC_SRV

# Web
		WEB_SRV=10.1.1.10
		/usr/sbin/iptables -t nat -A PREROUTING		\
			-i $EXT_IF				\
			-p tcp --dport 8080			\
			-j DNAT --to-destination $WEB_SRV:80

# ICQ
		ICQ_SRV=10.1.1.10
		/usr/sbin/iptables -t nat -A PREROUTING		\
			-i $EXT_IF				\
			-p tcp --dport 3960:4000		\
			-j DNAT --to-destination $ICQ_SRV


# Quake
		QUAKE_SRV=10.1.1.10
		/usr/sbin/iptables -t nat -A PREROUTING		\
			-i $EXT_IF				\
			-p udp --dport 26000			\
			-j DNAT --to-destination $QUAKE_SRV

# identd
		IDENTD_SRV=10.1.1.10
		/usr/sbin/iptables -t nat -A PREROUTING		\
			-i $EXT_IF				\
			-p tcp --dport 113			\
			-j DNAT --to-destination $IDENTD_SRV


		echo 0 > /proc/sys/net/ipv4/conf/$EXT_IF/rp_filter
		echo 1 > /proc/sys/net/ipv4/ip_forward
		;;

	stop)
		echo "Removing firewall rules..."
		echo 0 > /proc/sys/net/ipv4/ip_forward
		/usr/sbin/iptables -F
		/usr/sbin/iptables -t nat -F
		;;

	restart)
		$0 stop	&&
		$0 start
		;;

	*)	echo "Usage: $0 {start|stop|restart}"
		;;

esac
